@@ -5,10 +5,11 @@ PROGRAM = 'Xephyr'
 URL = None
 PACKAGE = 'xephyr'
 
+
 class XephyrDisplay(AbstractDisplay):
     '''
     Xephyr wrapper
-    
+
     Xephyr is an X server outputting to a window on a pre-existing X display
     '''
     def __init__(self, size=(1024, 768), color_depth=24, bgcolor='black'):
@@ -24,15 +25,15 @@ class XephyrDisplay(AbstractDisplay):
 
     @classmethod
     def check_installed(cls):
-        EasyProcess([PROGRAM, '-help'], url=URL, ubuntu_package=PACKAGE).check_installed()
+        EasyProcess([PROGRAM, '-help'], url=URL,
+                    ubuntu_package=PACKAGE).check_installed()
 
     @property
     def _cmd(self):
-        cmd = [PROGRAM ,
+        cmd = [PROGRAM,
                dict(black='-br', white='-wr')[self.bgcolor],
-                '-screen',
-                'x'.join(map(str, list(self.size) + [self.color_depth])),
-                 self.new_display_var,
-                 ]
+               '-screen',
+               'x'.join(map(str, list(self.size) + [self.color_depth])),
+               self.new_display_var,
+               ]
         return cmd
-    
